<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=ru
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'activer_plugin' => 'Включить плагин',
	'affichage' => 'Показать',
	'aide_non_disponible' => 'Этот раздел  он-лайн помощи еще не переведен на русский язык.',
	'annuler_recherche' => 'Отменить поиск',
	'auteur' => 'Автор:',
	'avis_acces_interdit' => 'Доступ запрещен.',
	'avis_article_modifie' => 'Внимание: @nom_auteur_modif@ вносил изменения в эту статью @date_diff@ минут назад',
	'avis_aucun_resultat' => 'Ничего не найдено',
	'avis_base_inaccessible' => 'Невозможно подключиться к базе @base@.',
	'avis_chemin_invalide_1' => 'Выбранный вами путь',
	'avis_chemin_invalide_2' => 'похоже не верно. Пожалуйста, вернитесь на предыдущую страницу и проверьте предоставленную информацию.',
	'avis_connexion_echec_1' => 'Не удалось подключится к SQL серверу.',
	'avis_connexion_echec_2' => 'Пожалуйста, вернитесь на предыдущую страницу и проверьте внесенную информацию.',
	'avis_connexion_echec_3' => '<b>N.B.</b> На многих серверах вы должны сделать запрос для включения вашего доступа к базе данных SQL перед тем, как использовать её. Если вы не можете установить соединение, убедитесь, что такой запрос действительно был сделан.',
	'avis_connexion_erreur_creer_base' => 'База данных не может быть создана.',
	'avis_connexion_erreur_nom_base' => 'Название базы может состоять только из латинских букв, цифр и знака нижнего подчеркивания.',
	'avis_connexion_ldap_echec_1' => 'Не удалось подключиться к LDAP.',
	'avis_connexion_ldap_echec_2' => 'Вернитесь на предыдущую страницу и проверьте введенную вами информацию.',
	'avis_connexion_ldap_echec_3' => 'Кроме того, не используйте поддержку LDAP для импорта пользователей.',
	'avis_deplacement_rubrique' => 'Внимание! В этом разделе находится  @contient_breves@ новостей@scb@: если вы перемещаете его, пожалуйста, поставьте отметку для подтверждения операции.',
	'avis_erreur_connexion_mysql' => 'Ошибка соединения с SQL ',
	'avis_espace_interdit' => ' <b>Запрещенная зона</b> <div>SPIP уже установлен.</div>',
	'avis_lecture_noms_bases_1' => 'Программа установки не может прочитать названия установленных баз данных.',
	'avis_lecture_noms_bases_2' => 'Ни одна из баз данных не доступна или функция, позволяющая внесение в список баз данных, была отключена в целях безопасности (лучше иметь большее количество хостов).',
	'avis_lecture_noms_bases_3' => 'В случае, если второй выбор был верен, возможно, что база данных, названная за Вашим логином, может быть использована:',
	'avis_non_acces_page' => 'У вас нет доступа к этой странице.',
	'avis_operation_echec' => 'Не удалось выполнить операцию.',
	'avis_operation_impossible' => 'Невозможно выполнить операцию',
	'avis_suppression_base' => 'ВНИМАНИЕ: удаление данных необратимо',

	// B
	'bouton_acces_ldap' => 'Добавить доступ к LDAP >>',
	'bouton_ajouter' => 'Добавить',
	'bouton_annuler' => 'Отмена',
	'bouton_cache_activer' => 'Включить кеширование',
	'bouton_cache_desactiver' => 'Временно отключить кеширование',
	'bouton_demande_publication' => 'Запрос на публикацию этой статьи',
	'bouton_desactive_tout' => 'Отключить все',
	'bouton_desinstaller' => 'Удалить',
	'bouton_effacer_tout' => 'Удалить ВСЕ',
	'bouton_envoyer_message' => 'Отправить сообщение',
	'bouton_fermer' => 'Закрыть',
	'bouton_mettre_a_jour_base' => 'Обновить базу данных',
	'bouton_modifier' => 'Изменить',
	'bouton_radio_afficher' => 'Показать',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Показывать в списке находящихся на сайте редакторов',
	'bouton_radio_envoi_annonces_adresse' => 'Отправить объявления на адрес:',
	'bouton_radio_envoi_liste_nouveautes' => 'Отправить список последних новостей',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Не показывать в списке находящихся на сайте редакторов',
	'bouton_radio_non_envoi_annonces_editoriales' => 'Не отправлять никаких редакционных объявлений',
	'bouton_redirection' => 'ПЕРЕАДРЕСОВЫВАТЬ',
	'bouton_reinitialiser_aux_valeurs_par_defaut' => 'Восстановить значения по умолчанию',
	'bouton_relancer_installation' => 'перезапуск установки',
	'bouton_reset_password' => 'Создать новый пароль и отправить по e-mail',
	'bouton_suivant' => 'Следующий',
	'bouton_tenter_recuperation' => 'Пробуем отремонтировать базу',
	'bouton_test_proxy' => 'Проверить прокси',
	'bouton_vider_cache' => 'Очистить кеш',

	// C
	'cache_modifiable_webmestre' => 'Этот параметр может быть изменен только вебмастером.',
	'calendrier_synchro' => 'Если вы используете календарь, совместимый с <b>iCal</b>, вы можете синхронизировать его с сайтом.',
	'config_activer_champs' => 'Включить следующие поля',
	'config_choix_base_sup' => 'Выберите базу на этом сервере',
	'config_erreur_base_sup' => 'SPIP не может отобразить список доступных баз данных',
	'config_info_base_sup' => 'Если вам необходим запрос других баз данных используя SPIP, независимо от того, находятся ли они на том же SQL сервере или где-нибудь еще, используйте форму, показанную ниже, для их описания. Если вы оставите некоторые поля пустыми, то связанные детали будут использоваться с основной базой данных.',
	'config_info_base_sup_disponibles' => 'Дополнительные базы данных для которых могут быть отправлены запросы:',
	'config_info_enregistree' => 'Новые настройки сохранены',
	'config_info_logos' => 'Каждому элементу сайта можно установить свой логотип и также логотип для отображения «при наведении мыши» ',
	'config_info_logos_utiliser' => 'Включить загрузку логотипов к материалам',
	'config_info_logos_utiliser_non' => 'Отключить загрузку логотипов к материалам',
	'config_info_logos_utiliser_survol' => 'Разрешить добавлять логотип для отображения «при наведении мыши»',
	'config_info_logos_utiliser_survol_non' => 'Запретить добавлять логотип для отображения «при наведении мыши»',
	'config_info_redirection' => 'Виртуальная статья - это возможность перенаправлять посетителей по произвольному URL, как на другую страницу этого сайта, так и на любую ссылку в интернете.',
	'config_redirection' => 'Виртуальные статьи (редирект)',
	'config_titre_base_sup' => 'Описание дополнительной базы данных',
	'config_titre_base_sup_choix' => 'Выберите дополнительную базу данных',
	'connexion_ldap' => 'Соединение:',
	'creer_et_associer_un_auteur' => 'Создать и добавить автора',

	// D
	'date_mot_heures' => ':',

	// E
	'ecran_securite' => ' + сервис безопасности @version@',
	'email' => 'email',
	'email_2' => 'email:',
	'en_savoir_plus' => 'подробнее',
	'entree_adresse_annuaire' => 'Справочник адресов',
	'entree_adresse_email' => 'E-mail',
	'entree_adresse_email_2' => 'E-mail',
	'entree_base_donnee_1' => 'Сервер базы данных',
	'entree_base_donnee_2' => '(Обычно - «localhost», но вы можете уточнить в настройках хостинга)',
	'entree_biographie' => 'Об авторе (краткая биография)',
	'entree_chemin_acces' => '<b>Войти</b> по пути:',
	'entree_cle_pgp' => 'Ваш PGP ключ',
	'entree_cle_pgp_2' => 'Ключ PGP ',
	'entree_contenu_rubrique' => '(Краткое содержание раздела.)',
	'entree_identifiants_connexion' => 'Логин и пароль',
	'entree_identifiants_connexion_2' => 'Информация о подключении',
	'entree_informations_connexion_ldap' => 'Пожалуйста укажите параметры подключения к LDAP. Вы можете получить эту информацию у вашего системного администратора.',
	'entree_infos_perso' => 'Об авторе',
	'entree_infos_perso_2' => 'Кто автор?',
	'entree_interieur_rubrique' => 'В разделе:',
	'entree_liens_sites' => '<b>Гиперссылка</b> (ссылка, сайт для посещения ...)',
	'entree_login' => 'Ваш логин',
	'entree_login_connexion_1' => 'Логин соединения',
	'entree_login_connexion_2' => '(Иногда соответствует вашему логину  FTP доступа и иногда остается пустым)',
	'entree_mot_passe' => 'Ваш пароль',
	'entree_mot_passe_1' => 'Пароль',
	'entree_mot_passe_2' => '(Иногда соответствует вашему паролю FTP  доступа и иногда остается пустым)',
	'entree_nom_fichier' => 'Пожалуйста, выберите файл с резервной копией @texte_compresse@:',
	'entree_nom_pseudo' => 'Ваше имя или псевдоним',
	'entree_nom_pseudo_1' => '(Ваше имя или псевдоним)',
	'entree_nom_pseudo_2' => 'Имя или псевдоним',
	'entree_nom_site' => 'Название вашего сайта',
	'entree_nom_site_2' => 'Название сайта',
	'entree_nouveau_passe' => 'Новый пароль',
	'entree_passe_ldap' => 'Пароль',
	'entree_port_annuaire' => 'Номер порта в каталоге',
	'entree_signature' => 'Подпись',
	'entree_titre_obligatoire' => '<b>Заголовок</b> [обязательно]<br />',
	'entree_url' => 'Адрес Вашего сайта',
	'entree_url_2' => 'URL',
	'erreur_connect_deja_existant' => 'Уже существует сервер с таким названием',
	'erreur_email_deja_existant' => 'Это email уже зарегистрирован.',
	'erreur_nom_connect_incorrect' => 'Недопустимое имя сервера',
	'erreur_plugin_attribut_balise_manquant' => 'Атрибут @attribut@ отсутствует в теге @balise@.',
	'erreur_plugin_desinstalation_echouee' => 'Не удалось удалить плагин, но вы можете отключить его.',
	'erreur_plugin_fichier_absent' => 'Не хватает файла(ов)',
	'erreur_plugin_fichier_def_absent' => 'Отсутствует описание файла ',
	'erreur_plugin_nom_fonction_interdit' => 'Запрещенное название функции',
	'erreur_plugin_nom_manquant' => 'Отсутствует название плагина ',
	'erreur_plugin_prefix_manquant' => 'Неопределено пространство имен плагина',
	'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; отсутствует в файле описания',
	'erreur_plugin_version_manquant' => 'Отсутствует версия плагина',

	// H
	'htaccess_a_simuler' => 'Внимание: в настройках веб-сервера отключено использование @htaccess@ файлов. Для обеспечение достаточного уровня безопасности внесите изменения в настройки сервера самостоятельно или обратитесь в техническую поддержку хостинга. 
Также вы можете задать константы @constantes@ (в файле mes_options.php) так, чтобы эти файлы находились вне папки @document_root@.',
	'htaccess_inoperant' => 'htaccess не рабочий',

	// I
	'ical_info1' => 'Эта страница представляет Вам несколько методов для поддержки связи с деятельностью этого сайта',
	'ical_info2' => 'Вы можете узнать больше в <a href="@spipnet@">документации о SPIP </a>.',
	'ical_info_calendrier' => 'В вашем распоряжении есть два календаря. Первый - это карта сайта, показывающая все опубликованные статьи. Второй содержит редакторские объявления, а также ваши личные сообщения: он сохранен для вас, благодаря ключу, который вы можете изменить в любое время, подтвердив свой пароль.',
	'ical_methode_http' => 'Загрузить',
	'ical_methode_webcal' => 'Синхронизация (webcal://)',
	'ical_texte_js' => 'Вы можете вставить этот javascript код на любой сайт для того, что бы отображать последние опубликованные статьи и материалы вашего сайта.',
	'ical_texte_prive' => 'Этот календарь является строго личным, он информирует вас о работе со статьями на этом сайте (задачи, персональные настройки, отправленные статьи и новости дня ...).',
	'ical_texte_public' => 'Этот календарь позволяет Вам следить за основной деятельностью этого сайта (публикация статей и новостей).',
	'ical_texte_rss' => 'Вы можете экспортировать последние обновления на вашем сайте в формате XML/RSS (Rich Site Summary). Также этот формат данных позволяет импортировать информацию с других сайтов в Интернете (создавать синдицированные сайты). ',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Список адресатов',
	'ical_titre_rss' => 'Получение статей и новостей с других сайтов по RSS',
	'icone_accueil' => 'Главная',
	'icone_activer_cookie' => 'Поместить cookie',
	'icone_activite' => 'Обратная связь',
	'icone_admin_plugin' => 'Плагины',
	'icone_administration' => 'Обслуживание',
	'icone_afficher_auteurs' => 'Показать авторов',
	'icone_afficher_visiteurs' => 'Показать посетителей',
	'icone_arret_discussion' => 'Прекратить участие в этом обсуждении',
	'icone_calendrier' => 'Календарь',
	'icone_configuration' => 'Настройки',
	'icone_creer_auteur' => 'Создать автора и добавить к статье',
	'icone_creer_mot_cle' => 'Создать ключ и добавить к статье',
	'icone_creer_rubrique_2' => 'Новый раздел',
	'icone_developpement' => 'Разработка',
	'icone_edition' => 'Сайт',
	'icone_ma_langue' => 'Язык',
	'icone_mes_infos' => 'Профиль',
	'icone_mes_preferences' => 'Мои настройки',
	'icone_modifier_article' => 'Изменить статью',
	'icone_modifier_rubrique' => 'Изменить этот раздел',
	'icone_publication' => 'Публикации',
	'icone_relancer_signataire' => 'Опять связаться с подписавшимся',
	'icone_retour' => 'Назад',
	'icone_retour_article' => 'Назад к статье',
	'icone_squelette' => 'Шаблоны',
	'icone_suivi_publication' => 'Свежие обновления',
	'icone_supprimer_cookie' => 'Удалить cookie',
	'icone_supprimer_rubrique' => 'Удалить этот раздел',
	'icone_supprimer_signature' => 'Удалить эту подпись',
	'icone_valider_signature' => 'Подтвердить эту подпись',
	'image_administrer_rubrique' => 'Вы можете управлять этим разделом',
	'impossible_modifier_login_auteur' => 'Невозможно изменить логин.', # MODIF
	'impossible_modifier_pass_auteur' => 'Невозможно изменить пароль.', # MODIF
	'info_1_article' => '1 статья',
	'info_1_auteur' => '1 автор',
	'info_1_message' => '1 сообщение',
	'info_1_mot_cle' => '1 ключ',
	'info_1_rubrique' => '1 раздел',
	'info_1_visiteur' => '1 посетитель',
	'info_activer_cookie' => 'Вы можете включить <b>администраторский cookie</b>, который позволяет вам легко переключаться между основной и административной частью сайта.',
	'info_activer_menu_developpement' => 'Показать меню Développement',
	'info_admin_etre_webmestre' => 'Предоставить мне права вебмастера',
	'info_admin_je_suis_webmestre' => 'Я <b>вебмастер</b>',
	'info_admin_statuer_webmestre' => 'Сделать администратора вебмастером сайта',
	'info_admin_webmestre' => 'Администратор является <b>вебмастером</b>',
	'info_administrateur' => 'Администратор',
	'info_administrateur_1' => 'Aдминистратор',
	'info_administrateur_2' => 'на этом сайте (<i>использовать с осторожностью</i>)',
	'info_administrateur_site_01' => 'Если Вы администратор сайта, пожалуйста',
	'info_administrateur_site_02' => 'нажмите на эту ссылку',
	'info_administrateurs' => 'Администраторы',
	'info_administrer_rubrique' => 'Вы можете управлять этим разделом',
	'info_adresse' => 'на адрес:',
	'info_adresse_desinscription' => 'Отменить подписку по адресу:',
	'info_adresse_url' => 'Адрес сайта (URL)',
	'info_afficher_par_nb' => 'Показать',
	'info_aide_en_ligne' => 'SPIP Oнлайн Помощь',
	'info_ajout_image' => 'Когда вы добавляете изображения как прикрепленные документы к  статье, SPIP может автоматически создать уменьшенную копию  вставленных изображений. Это позволит, например, автоматически создавать галерею или портфолио.',
	'info_ajouter_rubrique' => 'Добавить другой раздел для управления:',
	'info_annonce_nouveautes' => 'Анонсы последних новостей',
	'info_article' => 'статья',
	'info_article_2' => 'статьи',
	'info_article_a_paraitre' => 'Статьи, которые будут опубликованы в будущем',
	'info_articles_02' => 'статьи',
	'info_articles_2' => 'Статьи',
	'info_articles_auteur' => 'Статьи этого автора',
	'info_articles_miens' => 'Мои статьи',
	'info_articles_tous' => 'Все статьи',
	'info_articles_trouves' => 'Найденные статьи',
	'info_attente_validation' => 'Ваши статьи на утверждении',
	'info_aucun_article' => 'Нет статей',
	'info_aucun_auteur' => 'Нет авторов',
	'info_aucun_message' => 'Нет сообщений',
	'info_aucun_rubrique' => 'Нет разделов',
	'info_aujourdhui' => 'сегодня:',
	'info_auteur_gere_rubriques' => 'Этот автор управляет следующими рубриками:',
	'info_auteur_gere_toutes_rubriques' => 'Этот автор управляет <b>всеми разделами</b>',
	'info_auteur_gere_toutes_rubriques_2' => 'Я управляю <b>всеми разделами</b>',
	'info_auteurs' => 'Авторы',
	'info_auteurs_par_tri' => 'Авторы@partri@',
	'info_auteurs_trouves' => 'Найденные авторы',
	'info_authentification_externe' => 'Внешнее подтверждение подлинности',
	'info_avertissement' => 'Предупреждение',
	'info_barre_outils' => 'с панелью инструментов?',
	'info_base_installee' => 'Структура вашей базы данных установлена.',
	'info_bio' => 'Биография',
	'info_cache_desactive' => 'Кеширование временно отключено.',
	'info_chapeau' => 'Введение',
	'info_chapeau_2' => 'Введение:',
	'info_chemin_acces_1' => 'Опции: <b>Путь доступа к каталогу</b>',
	'info_chemin_acces_2' => 'Теперь вы должны настроить путь доступа к каталогу информации. Эта информация необходима для просмотра профилей пользователей, хранящихся в каталоге.',
	'info_chemin_acces_annuaire' => 'Опции: <b>Путь доступа к каталогу</b>',
	'info_choix_base' => 'Третий этап:',
	'info_classement_1' => ' из @liste@',
	'info_classement_2' => ' из @liste@',
	'info_code_acces' => 'Не забудьте свой пароль!',
	'info_config_suivi' => 'Если этот адрес соответствует списку e-mail рассылки, вы можете указать ниже адрес, по которому участники сайта могут зарегистрироваться. Этим адресом может быть адрес сайта (например страница списка регистрации через сеть) или адрес электронной почты с определенной темой (например: <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => 'Вы можете подписаться на почтовую рассылку этого сайта. Тогда вы будете получать на email информацию о статьях и новостях, отправленных для публикации.',
	'info_confirmer_passe' => 'Подтвердите новый пароль:',
	'info_conflit_edition_avis_non_sauvegarde' => 'Внимание: следующие поля были изменены в другом месте. Поэтому ваши изменения в этих полях не были сохранены.',
	'info_conflit_edition_differences' => 'Различия:',
	'info_conflit_edition_version_enregistree' => 'Сохраненная версия:',
	'info_conflit_edition_votre_version' => 'Ваша версия:',
	'info_connexion_base' => 'Второй этап: <b>подключение к базе данных</b>',
	'info_connexion_base_donnee' => 'Параметры подключение к базе данных',
	'info_connexion_ldap_ok' => '<b>Cоединение c LDAP установлено. </b> <p>Вы можете перейти к следующему шагу.</p>',
	'info_connexion_mysql' => 'Подключение к SQL',
	'info_connexion_ok' => 'Соединение установлено.',
	'info_contact' => 'Контакт',
	'info_contenu_articles' => 'Содержание статей',
	'info_contributions' => 'Contributions',
	'info_creation_paragraphe' => '(Разделяйте абзацы пустыми строками)',
	'info_creation_rubrique' => 'Создайте хотя бы один раздел для того, чтобы создавать статьи.<br />',
	'info_creation_tables' => 'Четвертый этап: <b>Создание таблиц базы данных</b>',
	'info_creer_base' => '<b>Создать</b> новую базу данных:',
	'info_dans_rubrique' => 'В разделе:',
	'info_date_publication_anterieure' => 'Дополнительная дата:',
	'info_date_referencement' => 'ДАТА ССЫЛКИ НА ЭТОТ САЙТ:',
	'info_derniere_etape' => 'Готово!',
	'info_descriptif' => 'Описание:',
	'info_desinstaller_plugin' => 'удалить файлы и отключить плагин',
	'info_discussion_cours' => 'Текущие обсуждения',
	'info_ecrire_article' => 'Перед тем как написать статью, вы должны создать хотя бы один раздел.',
	'info_email_envoi' => 'Адрес электронной почты отправителя (дополнительно)',
	'info_email_envoi_txt' => 'Введите используемый адрес электронной почты отправителя, посылая электронные письма (по умолчанию, адрес получателя используется как адрес отправителя), :',
	'info_email_webmestre' => 'E-mail веб-мастера',
	'info_envoi_email_automatique' => 'Автоматическая рассылка',
	'info_envoyer_maintenant' => 'Отправить сейчас',
	'info_etape_suivante' => 'Перейти к следующему этапу',
	'info_etape_suivante_1' => 'Вы можете перейти к следующему этапу.',
	'info_etape_suivante_2' => 'Вы можете перейти к следующему этапу.',
	'info_exceptions_proxy' => 'Исключения для прокси',
	'info_exportation_base' => 'экспортировать базу данных в @archive@',
	'info_facilite_suivi_activite' => 'Для облегчения проверки исполнения редактирования сайта;
 SPIP может рассылать уведомления по электронной почте, для редакторской почтовой рассылки например,
 прошение о публикации и утверждение статьи.', # MODIF
	'info_fichiers_authent' => 'Файл подтверждения подлинности «.htpasswd»',
	'info_forums_abo_invites' => 'Ваш сайт содержит форумы по подписке; посетители могут зарегистрироваться на них на основном сайте.',
	'info_gauche_admin_tech' => '<b>Страница только для вебмастера сайта.</b> <p>Вы можете выполнять задачи по эксплуатации сайта. Часть из них может потребовать  FTP доступа к сайту.</p>',
	'info_gauche_admin_vider' => '<b>Только вебмастера имеют доступ к этой странице. </b><p>Тут есть возможность выполнять разные задачи по обслуживанию сайта. Для выполнения отдельных задач необходима доступ к сайту по FTP.</p>',
	'info_gauche_auteurs' => 'Список всех авторов сайта. 
Статус автора обозначен цветом (администратор = зеленый; автор = желтый).',
	'info_gauche_auteurs_exterieurs' => 'Зарегистрированные пользователи обозначены синим цветом, а удаленные пользователи - иконкой корзины.',
	'info_gauche_messagerie' => 'Передача сообщений позволяет обмениваться сообщениями между редакторами, сохранять записки (для вашего личного использования) или показывать объявления на основной странице административной части (если вы - администратор).',
	'info_gauche_statistiques_referers' => 'Эта страница показывает список <i> ссылок</i>, то есть сайты, содержащие ссылки на ваш личный сайт, только для вчера и сегодня: фактически этот список обновляется каждые 24 часа.',
	'info_gauche_visiteurs_enregistres' => 'Вы найдете здесь пользователей, зарегистрированных в основной части сайта (форумы по подписке).',
	'info_generation_miniatures_images' => 'Создание уменьшенных изображений',
	'info_gerer_trad_objets' => '@objets@ : управление переводами',
	'info_hebergeur_desactiver_envoi_email' => 'Некоторые хосты отключают  автоматизированную отправку писем 
  на своих серверах. В этом случае следующие возможности 
 SPIP не могут быть осуществлены.',
	'info_hier' => 'вчера:',
	'info_identification_publique' => 'Ваша публичная идентификация...',
	'info_image_process' => 'Выберите лучший метод для создания уменьшенной копии, нажимая на соответствующую картинку.',
	'info_image_process2' => 'Если картинки не отображаются -значит ваш хостинг не поддерживает расширения по работе с изображениями. Уточните в тех. поддержке хостинга о возможности использовать библиотеки «GD» или «Imagemagic».',
	'info_images_auto' => 'Кеш файлов изображений',
	'info_informations_personnelles' => 'Настройки профиля',
	'info_inscription' => 'Зарегистрирован',
	'info_inscription_automatique' => 'Автоматическая регистрация новых авторов',
	'info_jeu_caractere' => 'Кодировка сайта',
	'info_jours' => 'дни',
	'info_laisser_champs_vides' => 'оставьте эти поля пустыми)',
	'info_langues' => 'Языки сайта',
	'info_ldap_ok' => 'Установление подлинности LDAP.',
	'info_lien_hypertexte' => 'Гиперссылка:',
	'info_liste_nouveautes_envoyee' => 'Информация о последних обновлениях отправлена',
	'info_liste_redacteurs_connectes' => 'Авторы онлайн',
	'info_login_existant' => 'Этот логин уже используется.',
	'info_login_trop_court' => 'Слишком короткий логин.',
	'info_login_trop_court_car_pluriel' => 'Логин должен состоять минимум из @nb@ символов.',
	'info_logos' => 'Логотипы',
	'info_maximum' => 'максимум:',
	'info_meme_rubrique' => 'В этом разделе:',
	'info_message_en_redaction' => 'Ваше сообщение в ходе работы',
	'info_message_technique' => 'Техническое сообщение:',
	'info_messagerie_interne' => 'Внутренняя передача сообщений',
	'info_mise_a_niveau_base' => 'обновление базы данных SQL',
	'info_mise_a_niveau_base_2' => '{{Предупреждение!}} Вы установили версию 
  SPIP файлов {старше} чем та, которая была 
  предварительно установлена на этом сайте: Ваша база данных подвергается риску быть потерянной 
  и Ваш сайт больше не будет работать должным образом. <br /> {{Переустановите 
 SPIP Файлы.}}',
	'info_modification_enregistree' => 'Ваши изменения сохранены',
	'info_modifier_auteur' => 'Изменить автора:',
	'info_modifier_rubrique' => 'Изменить раздел:',
	'info_modifier_titre' => 'Изменить: @titre@',
	'info_mon_site_spip' => 'Мой сайт ',
	'info_moyenne' => 'в среднем:',
	'info_multi_cet_article' => 'Язык этой статьи:',
	'info_multi_langues_choisies' => 'Выберите языки для материалов на сайте. Вы не можете отключить уже используемые языки.
  Языки, уже используемые Вашим сайтом(в верху списка) не могут быть отключены.',
	'info_multi_objets' => '@objets@ : включить языковое меню',
	'info_multi_secteurs' => '... только для разделов в корне сайта?',
	'info_nb_articles' => '@nb@ статей',
	'info_nb_auteurs' => '@nb@ авторов',
	'info_nb_messages' => '@nb@ сообщений',
	'info_nb_mots_cles' => '@nb@ ключей',
	'info_nb_rubriques' => '@nb@ разделов',
	'info_nb_visiteurs' => '@nb@ посетителей',
	'info_nom' => 'Имя',
	'info_nom_destinataire' => 'Имя получателя',
	'info_nom_pas_conforme' => 'нельзя использовать html теги',
	'info_nom_site' => 'Название Вашего сайта',
	'info_nombre_articles' => '@nb_articles@ статьи,',
	'info_nombre_rubriques' => '@nb_rubriques@ разделы,',
	'info_nombre_sites' => '@nb_sites@ сайты,',
	'info_non_deplacer' => 'Не перемещать ...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP может регулярно отправлять новости, объявления сайта
  (недавно изданные статьи и новости).',
	'info_non_envoi_liste_nouveautes' => 'Не отправлять список последних новостей',
	'info_non_modifiable' => 'не может быть изменен',
	'info_non_suppression_mot_cle' => 'Я не хочу удалять этот ключ.',
	'info_notes' => 'Примечания',
	'info_nouvel_article' => 'Новая статья',
	'info_nouvelle_traduction' => 'Новый перевод:',
	'info_numero_article' => 'НОМЕР СТАТЬИ:',
	'info_obligatoire_02' => '(обязательно)', # MODIF
	'info_option_accepter_visiteurs' => 'Включить регистрацию посетителей на сайте',
	'info_option_ne_pas_accepter_visiteurs' => 'Отключить регистрацию посетителей на сайте',
	'info_options_avancees' => 'ДОПОЛНИТЕЛЬНЫЕ НАСТРОЙКИ',
	'info_ou' => 'или...',
	'info_page_interdite' => 'Запрещенная страница',
	'info_par_nom' => 'по названию',
	'info_par_nombre_article' => 'по номерам статей',
	'info_par_statut' => 'по статусу',
	'info_par_tri' => '’(по @tri@)’',
	'info_passe_trop_court' => 'Пароль слишком короткий.',
	'info_passe_trop_court_car_pluriel' => 'Пароль должен содержать минимум @nb@ символов.',
	'info_passes_identiques' => 'Два пароля не совпадают.',
	'info_plus_cinq_car' => 'более 5 символов',
	'info_plus_cinq_car_2' => '(Более 5 символов)',
	'info_plus_trois_car' => '(Более 3 символов)',
	'info_popularite' => 'популярность: @popularite@; посещения: @visites@',
	'info_post_scriptum' => 'Постскриптум',
	'info_post_scriptum_2' => 'Постскриптум: ',
	'info_pour' => 'для',
	'info_preview_texte' => 'Использование предварительного просмотра. Вы можете посмотреть как выглядят на сайте  материалы со статусом «утверждается». Включить эту возможность для всех авторов, только для администраторов или отключить вообще?',
	'info_procedez_par_etape' => 'пожалуйста, выполняйте шаг за шагом',
	'info_procedure_maj_version' => 'необходимо запустить процедуру обновления текущей базы данных для новой версии SPIP.',
	'info_proxy_ok' => 'Прокси сервер работает.',
	'info_ps' => 'P.S.',
	'info_publier' => 'опубликовать',
	'info_publies' => 'Ваши статьи, опубликованные на сайте:',
	'info_question_accepter_visiteurs' => 'Если шаблоны Вашего сайта позволяют посетителям регистрироваться, не входя в административную часть, пожалуйста включите следующую опцию:',
	'info_question_inscription_nouveaux_redacteurs' => 'Вы хотите разрешить посетилям регистрироваться на сайте? Если да, то они смогут регистрироваться самостоятельно, используя стандартную форму. Они также получат доступ в административную часть сайта и возможность создавать новые материалы.  <div class="notice"> Пароль для входа будет отправлен новому пользователю автоматически, на его email адрес. Если ваш хостинг не поддерживает отправку писем, то автоматическая регистрация не будет работать.</div>',
	'info_qui_edite' => '@nom_auteur_modif@ работал над этим материалом @date_diff@ минут назад',
	'info_racine_site' => 'Корень сайта',
	'info_recharger_page' => 'Пожалуйста перезагрузите эту страницу через несколько минут.',
	'info_recherche_auteur_zero' => 'Ничего не найдено по запросу «@cherche_auteur@».',
	'info_recommencer' => 'Пожалуйста попробуйте еще раз.',
	'info_redacteur_1' => 'Автор',
	'info_redacteur_2' => 'имея доступ к административной части(<i> рекомендовал </i>), ',
	'info_redacteurs' => 'Авторы',
	'info_redaction_en_cours' => 'РЕДАКТИРУЕТСЯ',
	'info_redirection' => 'Перенаправление',
	'info_redirection_activee' => 'Перенаправление включено.',
	'info_redirection_boucle' => 'Вы пытаетесь перенаправить статью саму на себя.',
	'info_redirection_desactivee' => 'Перенаправление удалено.',
	'info_refuses' => 'Ваши отклоненные статьи',
	'info_reglage_ldap' => 'Опции<b> Настройка импорта LDAP</b>',
	'info_renvoi_article' => 'Посетитель будет перенаправлен по следующей ссылке',
	'info_reserve_admin' => 'Только администраторы могут изменить этот адрес.',
	'info_restreindre_rubrique' => 'Ограничить управление разделом:',
	'info_resultat_recherche' => 'Результаты поиска:',
	'info_rubriques' => 'Разделы',
	'info_rubriques_02' => 'разделы',
	'info_rubriques_trouvees' => 'Найденные разделы',
	'info_sans_titre' => 'Без названия',
	'info_selection_chemin_acces' => '<b>Выберите</b>  путь доступа к каталогу:',
	'info_signatures' => 'подписи',
	'info_site' => 'Сайт',
	'info_site_2' => 'Сайт:',
	'info_site_min' => 'сайт',
	'info_site_reference_2' => 'Ссылающийся сайт',
	'info_site_web' => 'САЙТ:',
	'info_sites' => 'сайты',
	'info_sites_lies_mot' => 'Сайты с этим ключом',
	'info_sites_proxy' => 'Использовать прокси',
	'info_sites_trouves' => 'Найденные сайты',
	'info_sous_titre' => 'Подзаголовок:',
	'info_statut_administrateur' => 'Администратор',
	'info_statut_auteur' => 'Права доступа:',
	'info_statut_auteur_2' => 'Я',
	'info_statut_auteur_a_confirmer' => 'Регистрация будет подтверждена',
	'info_statut_auteur_autre' => 'Другой статус:',
	'info_statut_redacteur' => 'Автор',
	'info_statut_utilisateurs_1' => 'Статус по умолчанию для импортированных пользователей',
	'info_statut_utilisateurs_2' => 'Выберите статус, характерный для  присутствующих людей в каталоге LDAP, когда они подключаются впервые. Позже, Вы можете изменить это значение для каждого автора индивидуально.',
	'info_suivi_activite' => 'Работа с материалами',
	'info_surtitre' => 'Надзаголовок:',
	'info_syndication_integrale_1' => 'Ваш сайт предлагает объединенные файлы  (смотрите «<a href="@url@">@titre@</a>»).',
	'info_syndication_integrale_2' => 'Отправить статью полностью или только первые абзацы?',
	'info_table_prefix' => 'Вы можете задать свой префикс для имен таблиц базы данных (благодаря этому вы можете установить несколько сайтов на одну базу данных). Для написания префикса используйте только прописные латинские буквы и цифры.',
	'info_taille_maximale_images' => 'Максимальный размер  картинок, с которыми может работать SPIP. Размер в картинок в пикселях.<br /> SPIP не сможет пережимать картинки большего размера.',
	'info_taille_maximale_vignette' => 'Максимальный размер изображений, созданных системой:',
	'info_terminer_installation' => 'Теперь Вы можете закончить стандартный процесс установки.',
	'info_texte' => 'Текст',
	'info_texte_explicatif' => 'Объяснительный текст',
	'info_texte_long' => '(Длинный текст: он появится в нескольких частях, которые будут повторно собраны после утверждения.)',
	'info_texte_message' => 'Текст сообщения:',
	'info_texte_message_02' => 'Текст сообщения',
	'info_titre' => 'Заголовок:',
	'info_total' => 'всего:',
	'info_tous_articles_en_redaction' => 'Все редактируемые статьи',
	'info_tous_articles_presents' => 'Все статьи в этом разделе',
	'info_tous_articles_refuses' => 'Все отклоненные статьи',
	'info_tous_les' => 'каждый:',
	'info_tout_site' => 'Весь сайт',
	'info_tout_site2' => 'Статья не была переведена на этот язык.',
	'info_tout_site3' => 'Статья была переведена на этот язык, но с тех пор в оригинал внесли изменения. Необходимо обновить перевод.',
	'info_tout_site4' => 'Статья была переведена на этот язык, и перевод современен.',
	'info_tout_site5' => 'Исходная статья.',
	'info_tout_site6' => '<b>Предупреждение:</b> отображаются только исходные статьи.
Переводы связанные с оригиналом, 
 в цвете указывающем на их статус:в цвете, указывающем их статус:',
	'info_traductions' => 'Переводы',
	'info_travail_colaboratif' => 'Совместная работа над статьями',
	'info_un_article' => 'статья,',
	'info_un_site' => 'сайт,',
	'info_une_rubrique' => 'раздел,',
	'info_une_rubrique_02' => '1 раздел',
	'info_url' => 'Адрес:',
	'info_url_proxy' => 'URL прокси',
	'info_url_proxy_pas_conforme' => 'URL прокси указан неверно.',
	'info_url_site_pas_conforme' => 'неправильный URL сайта.',
	'info_url_test_proxy' => 'URL для проверки',
	'info_urlref' => 'Гиперссылка:',
	'info_utilisation_spip' => 'SPIP готов к работе',
	'info_visites_par_mois' => 'Ежемесячный показ:',
	'info_visiteur_1' => 'Посетитель',
	'info_visiteur_2' => 'из основной части сайта',
	'info_visiteurs' => 'Посетители',
	'info_visiteurs_02' => 'Посетители основной части сайта',
	'info_webmestre_forces' => 'Список вебмастеров содержится в <tt>@file_options@</tt>.',
	'install_adresse_base_hebergeur' => 'Адрес сервера базы данных вы можете узнать у своего хостера',
	'install_connect_ok' => 'Была объявлена новая база на сервере @connect@.',
	'install_echec_annonce' => 'Эта установка вероятно не будет работать, или приведет к неустойчивой работе сайта...',
	'install_extension_mbstring' => 'SPIP не работает с:',
	'install_extension_php_obligatoire' => 'SPIP требует php расширений:',
	'install_login_base_hebergeur' => 'Логин определяется поставщиком услуг',
	'install_nom_base_hebergeur' => 'Имя базы данных определяется поставщиком услуг:',
	'install_pas_table' => 'В базе данных еще нет таблиц',
	'install_pass_base_hebergeur' => 'Вы можете установить пароль через контрольную панель хостинга или запросить его в службе поддержки вашего хостинга.',
	'install_php_version' => 'Версия PHP  @version@ слишком старая (минимум = @minimum@)',
	'install_select_langue' => 'Выберите язык, потом нажмите кнопку «далее», чтобы начать процедуру установки.',
	'install_select_type_db' => 'Укажите тип базы данных:',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_pg' => 'PostgreSQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_serveur_hebergeur' => 'Сервер базы данных определяется поставщиком услуг',
	'install_table_prefix_hebergeur' => 'Префикс таблицы базы данных:',
	'install_tables_base' => 'Таблицы баз данных',
	'install_types_db_connus' => 'SPIP работает с <b>MySQL</b> и <b>SQLite</b>.',
	'install_types_db_connus_avertissement' => 'Поддержка PostgreSQL пока на экспериментальном уровне. ',
	'instituer_erreur_statut_a_change' => 'Статус уже был изменен',
	'instituer_erreur_statut_non_autorise' => 'Вы не можете выбрать этот статус',
	'intem_redacteur' => 'редактор',
	'intitule_licence' => 'Разрешение',
	'item_accepter_inscriptions' => 'Позволить регистрацию',
	'item_activer_messages_avertissement' => 'Предупреждать о совместной работе',
	'item_administrateur_2' => 'администратор',
	'item_afficher_calendrier' => 'Показывать в календаре',
	'item_autoriser_syndication_integrale' => 'Включать целые статьи в объединенные файлы ',
	'item_choix_administrateurs' => 'администраторы',
	'item_choix_generation_miniature' => 'Создавать уменьшенные копии автоматически.',
	'item_choix_non_generation_miniature' => 'Не создавать уменьшенные копии.',
	'item_choix_redacteurs' => 'редакторы',
	'item_choix_visiteurs' => 'посетители сайта',
	'item_creer_fichiers_authent' => 'Создать .htpasswd файлы',
	'item_login' => 'Логин',
	'item_messagerie_agenda' => 'Включить систему обмена сообщениями и календарь',
	'item_mots_cles_association_articles' => 'статьи',
	'item_mots_cles_association_rubriques' => 'разделы',
	'item_mots_cles_association_sites' => 'сослаться или объединить сайты.',
	'item_non' => 'Нет',
	'item_non_accepter_inscriptions' => 'Не разрешать регистрацию',
	'item_non_activer_messages_avertissement' => 'НЕ предупреждать о совместной работе',
	'item_non_afficher_calendrier' => 'Не показывать календарь',
	'item_non_autoriser_syndication_integrale' => 'Отправка только краткого изложения',
	'item_non_creer_fichiers_authent' => 'Не создавать эти файлы',
	'item_non_messagerie_agenda' => 'Отключить систему обмена сообщениями и календарь',
	'item_non_publier_articles' => 'Публиковать статьи только после указанной даты публикации.',
	'item_nouvel_auteur' => 'Новый автор',
	'item_nouvelle_rubrique' => 'Новый раздел',
	'item_oui' => 'Да',
	'item_publier_articles' => 'Немедленно публиковать статьи, вне зависимости от даты публикации',
	'item_reponse_article' => 'Ответить на статью',
	'item_visiteur' => 'посетитель',

	// J
	'jour_non_connu_nc' => 'неизвестный',

	// L
	'label_bando_outils' => 'Панель инструментов',
	'label_bando_outils_afficher' => 'Показать инструменты',
	'label_bando_outils_masquer' => 'Скрыть инструменты',
	'label_choix_langue' => 'Язык интерфейса',
	'label_nom_fichier_connect' => 'Отображать имя сервера',
	'label_slogan_site' => 'Слоган сайта',
	'label_taille_ecran' => 'Ширина рабочей области',
	'label_texte_et_icones_navigation' => 'Главное меню',
	'label_texte_et_icones_page' => 'Отображение страницы',
	'ldap_correspondance' => 'наследовать поле @champ@',
	'ldap_correspondance_1' => 'Наследовать поля LDAP',
	'ldap_correspondance_2' => 'Укажите соответствующее LDAP поле для каждого из данных полей. Оставьте их пустыми, если вы не хотите, чтобы они заполнялись. Несколько LDAP полей разделяются пробелом или запятой.',
	'lien_ajouter_auteur' => 'Добавить этого автора',
	'lien_ajouter_une_rubrique' => 'Добавить раздел',
	'lien_email' => 'Электронная почта',
	'lien_nom_site' => 'НАЗВАНИЕ САЙТА:',
	'lien_rapide_contenu' => 'Перейти к информации',
	'lien_rapide_navigation' => 'Перейти к навигации',
	'lien_rapide_recherche' => 'Перейти к поиску',
	'lien_retirer_auteur' => 'Убрать автора',
	'lien_retirer_rubrique' => 'Убрать раздел',
	'lien_retirer_tous_auteurs' => 'Убрать всех авторов',
	'lien_retirer_toutes_rubriques' => 'Убрать все разделы',
	'lien_site' => 'сайт',
	'lien_tout_decocher' => 'Снять все',
	'lien_tout_deplier' => 'Развернуть все ',
	'lien_tout_replier' => 'Свернуть все',
	'lien_tout_supprimer' => 'Удалить все',
	'lien_trier_nom' => 'Сортировать по имени',
	'lien_trier_nombre_articles' => 'Сортировать по номерам статей',
	'lien_trier_statut' => 'Сортировать по статусу',
	'lien_voir_en_ligne' => 'ПРОСМОТР ОНЛАЙН:',
	'logo_article' => 'ЛОГОТИП СТАТЬИ',
	'logo_auteur' => 'ЛОГОТИП АВТОРА',
	'logo_rubrique' => 'ЛОГОТИП РАЗДЕЛА',
	'logo_site' => 'ЛОГОТИП САЙТА',
	'logo_standard_rubrique' => 'Стандартный логотип раздела',
	'logo_survol' => 'ПРИ НАВЕДЕНИИ МЫШКИ',

	// M
	'menu_aide_installation_choix_base' => 'Выберите вашу базу данных',
	'module_fichier_langue' => 'Языковой файл',
	'module_raccourci' => 'Ярлык',
	'module_texte_affiche' => 'Показанный текст',
	'module_texte_explicatif' => 'Вы можете вставить следующие ярлыки в шаблон вашего сайта. Они будут автоматически переведены на те языки, для которых существует языковой файл.',
	'module_texte_traduction' => 'Языковой файл «@module@» является доступным в:',
	'mois_non_connu' => 'неизвестный',

	// N
	'nouvelle_version_spip' => 'Доступно обновление - версия SPIP @version@ ',
	'nouvelle_version_spip_majeure' => 'Доступна новая версия SPIP @version@ ',

	// O
	'onglet_contenu' => 'Содержания',
	'onglet_declarer_une_autre_base' => 'Объявить другую базу данных',
	'onglet_discuter' => 'Обсудить',
	'onglet_interactivite' => 'Интерактивность',
	'onglet_proprietes' => 'Свойства',
	'onglet_repartition_actuelle' => 'сейчас',
	'onglet_sous_rubriques' => 'Подразделы',

	// P
	'page_pas_proxy' => 'Эта страница не должна проходить через прокси',
	'pas_de_proxy_pour' => 'Если необходимо, укажите для каких компьютеров или доменов не следует применять прокси (например: @exemple@) ',
	'phpinfo' => 'Настройки PHP',
	'plugin_charge_paquet' => 'Загрузка архива файла @имя@',
	'plugin_charger' => 'Скачать',
	'plugin_erreur_charger' => 'ошибка: невозможно загрузить @zip@',
	'plugin_erreur_droit1' => 'Нет прав для записи в папку  <code>@dest@</code>.',
	'plugin_erreur_droit2' => 'Пожалуйста, проверьте права на запись  для этой папки (и при необходимости создайте ее). Или перепишите файлы по FTP.',
	'plugin_erreur_zip' => 'pclzip сбой: ошибка @status@',
	'plugin_etat_developpement' => 'в разработке',
	'plugin_etat_experimental' => 'экспериментальный',
	'plugin_etat_stable' => 'стабильный',
	'plugin_etat_test' => 'тестируется',
	'plugin_impossible_activer' => 'Невозможно включить плагин @plugin@',
	'plugin_info_automatique1' => 'Для того, чтобы разрешить  автоматическую установку плагинов:',
	'plugin_info_automatique1_lib' => 'Если вы хотите разрешить автоматическую установку этой библиотеки, то:',
	'plugin_info_automatique2' => 'Создать папку <code>@rep@</code> ;',
	'plugin_info_automatique3' => 'Установите права доступа на каталог (755 или 777).',
	'plugin_info_automatique_creer' => 'для создания в корне вебсайта.',
	'plugin_info_automatique_exemples' => 'Официальные RSS листы с плагинами:',
	'plugin_info_automatique_ftp' => 'Вы можете установить плагины по FTP в каталог <tt>@rep@</tt> ',
	'plugin_info_automatique_lib' => 'Некоторые плагины должны иметь возможность загружать файлы в каталог <code>lib/</code>. Возможно, его необходимо создать самостоятельно.',
	'plugin_info_automatique_liste' => 'Ваши плагины:',
	'plugin_info_automatique_liste_officielle' => 'официальные плагины',
	'plugin_info_automatique_liste_update' => 'Обновить списки',
	'plugin_info_automatique_ou' => 'или...',
	'plugin_info_automatique_select' => 'Выберите плагин, SPIP скачает и установит его в каталог <code>@rep@</code>. Если плагин уже установлен, он будет обновлен.',
	'plugin_info_credit' => 'Авторская информация',
	'plugin_info_erreur_xml' => 'Неправильная декларация плагина',
	'plugin_info_install_ok' => 'Установка прошла успешно',
	'plugin_info_necessite' => 'Необходимо:',
	'plugin_info_non_compatible_spip' => 'Плагин не совместим с текущей версией SPIP',
	'plugin_info_plugins_dist_1' => 'Эти плагины загружены и установлены в папке @plugins_dist@.',
	'plugin_info_plugins_dist_2' => 'Их нельзя отключить.',
	'plugin_info_telecharger' => 'загрузите с @url@ и установить в @rep@',
	'plugin_info_upgrade_ok' => 'Обновление прошло успешно',
	'plugin_librairies_installees' => 'Установленные библиотеки',
	'plugin_necessite_extension_php' => 'Требуется PHP-расширение @plugin@ версии @version@.',
	'plugin_necessite_extension_php_sans_version' => 'Требуется PHP-расширение @plugin@',
	'plugin_necessite_lib' => 'Для этого плагина необходима библиотека  @lib@',
	'plugin_necessite_php' => 'Требуется @plugin@ версии @version@.',
	'plugin_necessite_plugin' => 'Для этого плагина необходим @plugin@  @version@ или новее.',
	'plugin_necessite_plugin_sans_version' => 'Требуется плагин @plugin@',
	'plugin_necessite_spip' => 'Для этого плагина требуется SPIP @version@ или новее.',
	'plugin_source' => 'источник: ',
	'plugin_titre_automatique' => 'Автоматическая установка',
	'plugin_titre_automatique_ajouter' => 'Добавить плагин',
	'plugin_titre_installation' => 'Установить плагин @plugin@ ',
	'plugin_titre_modifier' => 'Мои плагины',
	'plugin_utilise_extension_php' => 'Используется PHP-расширение @plugin@ версии @version@.', # MODIF
	'plugin_utilise_php' => 'Используется @plugin@ версии @version@.', # MODIF
	'plugin_utilise_plugin' => 'Используйте плагин @plugin@ версии @version@.', # MODIF
	'plugin_zip_active' => 'Продолжить для активации',
	'plugin_zip_adresse' => 'Укажите ссылку на zip файла плагина для скачки, либо адрес RSS листа плагинов.',
	'plugin_zip_adresse_champ' => 'URL плагина (zip file) или RSS листа ',
	'plugin_zip_content' => 'Он содержит следующие файлы (@taille@), <br />готовые к установке в каталоге <code>@rep@</code>',
	'plugin_zip_installe_finie' => 'Файл @zip@ был распакован и установлен.',
	'plugin_zip_installe_rep_finie' => 'Файл @zip@ был распакован и установлен в каталоге @rep@ ',
	'plugin_zip_installer' => 'Теперь вы можете установить.',
	'plugin_zip_telecharge' => 'Файл @zip@ был скачан',
	'plugins_actif_aucun' => 'Нет включенных плагинов.',
	'plugins_actif_un' => 'Включен один плагин',
	'plugins_actifs' => '@count@ плагинов включено.',
	'plugins_actifs_liste' => 'Включенные ',
	'plugins_compte' => '@count@ плагины',
	'plugins_disponible_un' => 'Доступен один плагин',
	'plugins_disponibles' => '@count@ доступно плагинов.',
	'plugins_erreur' => 'Ошибка в плагинах: @plugins@',
	'plugins_liste' => 'Установленные плагины',
	'plugins_liste_dist' => 'Защищенные плагины',
	'plugins_recents' => 'Последние плагины',
	'plugins_tous_liste' => 'Все',
	'plugins_vue_hierarchie' => 'Иерархия',
	'plugins_vue_liste' => 'Список',
	'protocole_ldap' => 'Версия протокола:',

	// Q
	'queue_executer_maintenant' => 'Запустить',
	'queue_info_purger' => 'Вы можете удалить все текущие задачи и очистить всю очередь задач', # MODIF
	'queue_nb_jobs_in_queue' => 'В очереди @nb@ задач', # MODIF
	'queue_next_job_in_nb_sec' => 'Следующая задача  через @nb@ s', # MODIF
	'queue_no_job_in_queue' => 'Список задач пуст', # MODIF
	'queue_one_job_in_queue' => '1 задача в очереди', # MODIF
	'queue_purger_queue' => 'Очистить список задач', # MODIF
	'queue_titre' => 'Список задач', # MODIF

	// R
	'repertoire_plugins' => 'Папка:',
	'required' => '(обязательно)', # MODIF

	// S
	'sans_heure' => 'время неопределено',
	'statut_admin_restreint' => '(ограниченный администратор)',
	'statut_webmestre' => 'вебмастер',

	// T
	'tache_cron_asap' => 'CRON @function@ (ASAP)',
	'tache_cron_secondes' => 'CRON @function@ (каждые @nb@ с)',
	'taille_cache_image' => 'Кеш файлов изображений (автоматически пережатые картинки, изображения формул и текста, трасформированного в графику) занимает @taille@ в каталоге @dir@.',
	'taille_cache_infinie' => 'На вашем сайте нет ограничений на размер кеша.',
	'taille_cache_maxi' => 'Заданный максимальный размер файлов кеша составляет приблизительно <b> @octets@ </b>.',
	'taille_cache_moins_de' => 'Размер кеша меньше  @octets@.',
	'taille_cache_octets' => 'Приблизительный размер кеша @octets@.',
	'taille_cache_vide' => 'Кеш пуст.',
	'taille_repertoire_cache' => 'Текущий размер кеша',
	'text_article_propose_publication' => 'Статья отправлена на утверждение администратору.',
	'texte_acces_ldap_anonyme_1' => 'Некоторые серверы LDAP не позволяют анонимного доступа. В этом случае вы должны указать исходный идентификатор доступа, чтобы впоследствии иметь возможность искать информацию в каталоге. Однако, в большинстве случаев следующие поля можно оставить пустыми.',
	'texte_admin_effacer_01' => 'Эта команда удаляет <i>всё</i> содержание базы данных, 
включая <i>все</i> параметры доступа для редакторов и администраторов. После её выполнения вы должны 
переустановить SPIP, чтобы восстановить новую базу данных и доступ первого администратора.',
	'texte_adresse_annuaire_1' => '(Если ваш каталог установлен на том же компьютере, что ваш вебсайт, это вероятно «localhost».)',
	'texte_ajout_auteur' => 'Следующий автор был добавлен к статье:',
	'texte_annuaire_ldap_1' => 'Если вы имеете доступ к каталогу (LDAP), вы можете использовать его, для автоматического импорта пользователей под SPIP.',
	'texte_article_statut' => 'Статус статьи:',
	'texte_article_virtuel' => 'Виртуальная статья',
	'texte_article_virtuel_reference' => '<b>Виртуальная статья:</b> статья, на которую ссылаются на вашем SPIP сайте, но переадресованная на другой адрес. Чтобы удалить перенаправление, удалите вышеупомянутый адрес.',
	'texte_aucun_resultat_auteur' => 'Нет результатов для «@cherche_auteur@».',
	'texte_auteur_messagerie' => 'Этот сайт может постоянно контролировать список редакторов, находящихся он-лайн, который позволяет вам обмениваться сообщениями в реальном времени. Вы можете решить не появляться в этом списке (тогда вы будете «невидимы» для других пользователей).',
	'texte_auteurs' => 'АВТОРЫ',
	'texte_choix_base_1' => 'Выбрать Вашу базу данных:',
	'texte_choix_base_2' => 'SQL сервер содержит несколько баз данных.',
	'texte_choix_base_3' => '<b>Выберите</b> ниже ту, которую ваш интернет провайдер может отнести к вам:',
	'texte_choix_table_prefix' => 'Префикс для таблиц БД:',
	'texte_compte_element' => '@count@ элемент',
	'texte_compte_elements' => '@count@ элементы',
	'texte_conflit_edition_correction' => 'Пожалуйста, проверьте ниже разницу между двумя версиями. Вы также можете скопировать ваши изменения и начать всё заново.',
	'texte_connexion_mysql' => 'Параметры доступа к базе данных задаются в контрольной панели хостинга. Если у вас нет возможности управлять вашими базами данных вы можете запросить помощь в службе поддержки хостинга.',
	'texte_contenu_article' => '(Краткое содержание статьи.)',
	'texte_contenu_articles' => 'Выбрать дополнительные информационные поля для статей. В зависимости от того, как запрограммирован ваш сайт, они могут отображаться или не отображаться в общем доступе. ',
	'texte_crash_base' => 'Если ваша база данных повреждена, вы можете попробовать восстановить ее  автоматически.',
	'texte_creer_rubrique' => 'Создайте хотя бы один раздел, чтобы писать статьи.<br />',
	'texte_date_creation_article' => 'ДАТА СОЗДАНИЯ СТАТЬИ:',
	'texte_date_creation_objet' => 'Дата создания :', # on ajoute le ":"
	'texte_date_publication_anterieure' => 'Дополнительная дата:',
	'texte_date_publication_anterieure_nonaffichee' => 'Скрыть дату более ранней публикации.',
	'texte_date_publication_article' => 'ДАТА ОНЛАЙН ПУБЛИКАЦИИ:',
	'texte_date_publication_objet' => 'Дата публикации :',
	'texte_definir_comme_traduction_rubrique' => 'Этот раздел является переводом раздела с номером:',
	'texte_descriptif_rapide' => 'Краткое описание',
	'texte_effacer_base' => 'Удалить базу данных SPIP',
	'texte_effacer_statistiques' => 'Удалить статистику',
	'texte_en_cours_validation' => 'Материалы, требующие проверки. ',
	'texte_enrichir_mise_a_jour' => '<!—Вы можете улучшить свой текст, используя «типографические ярлыки»—>',
	'texte_fichier_authent' => '<b>Должен ли SPIP создавать <tt>.htpasswd</tt> и <tt>.htpasswd-admin</tt> файлы в папке @dossier@?</b><p>Эти файлы используются для ограничения доступа авторов и администраторов к другим частям  сайта (например, к папке с серверной статистикой). </p>
<p>Если у вас нет необходимости в таких действиях, то оставьте значение по умолчанию.</p>',
	'texte_informations_personnelles_1' => 'Теперь система создаст вашу учетную запись на сайте.',
	'texte_informations_personnelles_2' => '(Примечание: если вы переустанавливаете SPIP и ваш старый логин и пароль всё еще работают, вы можете',
	'texte_introductif_article' => '(Вступительный текст к статье)',
	'texte_jeu_caractere' => 'Рекомендуется использовать кодировку (<tt>utf-8</tt>) на вашем сайте. Это сделает возможным отображать текст на любом языке. ',
	'texte_jeu_caractere_3' => 'Текущая кодировка:',
	'texte_jeu_caractere_4' => 'Если это не соответствует ситуации, которую вы имеете с данными (например, после восстановления базы данных с резервной копии), или если <em>вы создаете этот сайт</em> и хотите использовать разные наборы символов, пожалуйста, укажите набор символов здесь:',
	'texte_login_ldap_1' => '(Держите пустым для анонимного доступа или введите полный путь, например «<tt>uid=smith, ou=users, dc=my-domain, dc=com</tt>».)',
	'texte_login_precaution' => 'Внимание! Это ваш текущий логин на сайте, меняйте вдумчиво.',
	'texte_messagerie_agenda' => 'Система отправки сообщений позволяет авторам сайта общаться непосредственно в редакторской части сайта. Она связана с календарем.',
	'texte_mise_a_niveau_base_1' => 'Вы только что обновили файлы SPIP 
 Теперь вы должны обновить базу данных сайта.',
	'texte_modifier_article' => 'Изменить статью:',
	'texte_multilinguisme' => 'Если на сайте будут размещаться материалы на нескольких языках, вы можете добавить «меню выбора языка» для этих материалов.',
	'texte_multilinguisme_trad' => 'Вы также можете разрешить объединять разные переводы одного и того же материала. ',
	'texte_non_compresse' => '<i>распаковать</i> (Ваш сервер не поддерживает эту функцию)',
	'texte_nouvelle_version_spip_1' => 'Вы только что установили новую версию SPIP.',
	'texte_nouvelle_version_spip_2' => 'Чтобы обновить сайт до новой версии, то, если вы - вебмастер этого сайта, пожалуйста, удалите файл @connect@ и повторно начните установку, чтобы обновить настройки подключения к базе данных.<p>(NB.: если вы забыли свои параметры соединения, то они хранятся в файле @connect@ </p>',
	'texte_operation_echec' => 'Вернитесь к предыдущей странице, выберите другую базу данных или создайте новую. Проверьте информацию, предоставленную вашим хостом.',
	'texte_plus_trois_car' => 'более 3 символов',
	'texte_plusieurs_articles' => 'Несколько авторов были найдены для «@cherche_auteur@»:',
	'texte_port_annuaire' => '(Значение по умолчанию является подходящим.)',
	'texte_presente_plugin' => 'На этой странице перечень плагинов, доступных на вашем сайте. Включите плагин, отметив соответствующий квадратик.',
	'texte_proposer_publication' => 'Когда ваша статья закончена, <br />вы можете представить ее для публикации.',
	'texte_proxy' => 'В некоторых случаях (внутренний интернет, защищенные сети ...), 
  необходимо использовать <i> HTTP прокси</i>, чтобы добраться до внешней части сайтов (SPIP документация, объединенные сайты и т. д.).  В этом случае, введите его адрес ниже в форме @proxy_en_cours@. В большинстве случаев вы можете оставить это поле пустым.',
	'texte_publication_articles_post_dates' => 'Когда публиковать статьи с датой публикации в будущем?',
	'texte_rappel_selection_champs' => '[Не забудьте правильно выбрать поле.]',
	'texte_recalcul_page' => 'Если вы хотите обновить только одну страницу, вы можете сделать это в основной части, используя кнопку, «обновить».',
	'texte_recuperer_base' => 'Востановить базу данных',
	'texte_reference_mais_redirige' => 'ссылка на статью вашего SPIP сайта, но переадресованная на другой адрес.',
	'texte_requetes_echouent' => '<b>В случае, если при выполнении SQL запросов часто появляются сообщения об ошибках, вполне возможно что повреждена сама база данных.  </b> 
<p>В SQL встроенна функция ремонта и восстановления поврежденных таблиц. Вы можете попробовать выполнить процедуру восстановления или ремонта сейчас.</p>
',
	'texte_selection_langue_principale' => 'Вы можете выбрать «главный  язык» сайта. Он задаёт: 
<ul>
<li>формат вывода даты по умолчанию;</li> 

<li>язык, используемый по умолчанию на сайте;</li> 

<li>язык по умолчанию для   административной части. </li> </ul>',
	'texte_sous_titre' => 'Подзаголовок',
	'texte_statistiques_visites' => '(темные штрихи: воскресенье / темная кривая: средний уровень)',
	'texte_statut_attente_validation' => 'в ожидании утверждения',
	'texte_statut_publies' => 'опубликованы на сайте',
	'texte_statut_refuses' => 'отклонено',
	'texte_suppression_fichiers' => 'Используйте команду для удаления всех файлов из кеша SPIP.  Это позволит обновить все страницы сайта. Это очень удобно, если вы изменили шаблоны или обновили значительное количество информации на сайте.',
	'texte_sur_titre' => 'Надзаголовок',
	'texte_table_ok' => ': эта таблица готова.',
	'texte_tentative_recuperation' => 'Попытка восстановления ',
	'texte_tenter_reparation' => 'Попытка восстановления базы данных',
	'texte_test_proxy' => 'Чтобы попробовать прокси, введите здесь адрес вебсайта, который вы хотите проверить.',
	'texte_titre_02' => 'Заглавие:',
	'texte_titre_obligatoire' => '<b>Заглавие</b> [обязательно]',
	'texte_travail_article' => '@nom_auteur_modif@ работал над этой статьей @date_diff@ минут назад',
	'texte_travail_collaboratif' => 'Если несколько авторов редактируют одну и ту же статью, то система отмечает ее как «в работе» и ограничивает доступ к ней, чтобы избежать потери информации вследствие одновременного редактирования материала. По умолчанию эта возможность отключена.',
	'texte_vide' => 'очистить',
	'texte_vider_cache' => 'Очистить кеш',
	'titre_admin_tech' => 'Техническое обслуживание',
	'titre_admin_vider' => 'Техническое обслуживание',
	'titre_ajouter_un_auteur' => 'Добавить автора',
	'titre_ajouter_un_mot' => 'Добавить ключ',
	'titre_cadre_afficher_article' => 'Показать статьи:',
	'titre_cadre_afficher_traductions' => 'Показать состояние перевода для следующих языков:',
	'titre_cadre_ajouter_auteur' => 'ДОБАВИТЬ АВТОРА:',
	'titre_cadre_interieur_rubrique' => 'В разделе',
	'titre_cadre_numero_auteur' => 'НОМЕР АВТОРА',
	'titre_cadre_numero_objet' => '@objet@ НОМЕР:',
	'titre_cadre_signature_obligatoire' => '<b>Подпись</b> [обязательно]<br />',
	'titre_config_contenu_notifications' => 'Уведомления',
	'titre_config_contenu_prive' => 'В редакторской части',
	'titre_config_contenu_public' => 'В основном сайте',
	'titre_config_fonctions' => 'Настройка сайта',
	'titre_config_langage' => 'Выбор языка интерфейса',
	'titre_configuration' => 'Настройка сайта',
	'titre_configurer_preferences' => 'Изменить настройки',
	'titre_configurer_preferences_menus' => 'Установите настройки меню', # RELIRE
	'titre_conflit_edition' => 'Конфликт в процессе изменения',
	'titre_connexion_ldap' => 'Опции: <b>ваше LDAP соединение</b>',
	'titre_groupe_mots' => 'ГРУППА КЛЮЧЕЙ:',
	'titre_identite_site' => 'Информация о сайте',
	'titre_langue_article' => 'Язык статьи',
	'titre_langue_rubrique' => 'ЯЗЫК РАЗДЕЛА',
	'titre_langue_trad_article' => 'ЯЗЫК СТАТЬИ И ПЕРЕВОДОВ',
	'titre_les_articles' => 'СТАТЬИ',
	'titre_messagerie_agenda' => 'Система обмена сообщениями и календарь',
	'titre_naviguer_dans_le_site' => 'Просмотр сайта...',
	'titre_nouvelle_rubrique' => 'Новый раздел',
	'titre_numero_rubrique' => 'НОМЕР РАЗДЕЛА:',
	'titre_page_articles_edit' => 'Изменить: @titre@',
	'titre_page_articles_page' => 'Статьи',
	'titre_page_articles_tous' => 'Весь сайт',
	'titre_page_calendrier' => 'Календарь @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Настройка сайта',
	'titre_page_delete_all' => 'полное и необратимое удаление',
	'titre_page_recherche' => 'Результаты поиска @recherche@',
	'titre_page_statistiques_referers' => 'Статистика  (входящие ссылки)',
	'titre_page_upgrade' => 'SPIP обновления',
	'titre_preference_menus_favoris' => 'Меню Избранные ',
	'titre_publication_articles_post_dates' => 'Отложенная публикация статей',
	'titre_reparation' => 'Восстановить',
	'titre_suivi_petition' => 'Отслеживание обращений (петиций)',
	'tls_ldap' => 'Transport Layer Security:',
	'trad_article_traduction' => 'Эта статья на разных языках:',
	'trad_delier' => 'Удалить связь с этим переводом',
	'trad_lier' => 'Эта статья - перевод статьи с номером:',
	'trad_new' => 'Добавить новый перевод',

	// U
	'utf8_convert_erreur_orig' => 'Ошибка: набор символов @charset@ не поддерживается.',

	// V
	'version' => 'Версия:'
);
